# Print output for @column tags ?>
These are the API classes. See all API packages.
| BarcodeType2 | BarcodeType represents the types of barcodes supported by the barcode scanning library. |
| ScannerIntent |
Defines the constants required for performing barcode scanning via an intent, and defines some classes and methods to simplify the scanning request process. |
| ScannerIntent.Request |
Creates an Intent used to make a request to the embedded Vuzix engine. |
| ScannerIntent.Request.Options | Options that can customize the behavior of the scanner |
| ScanResult2 | Represents a single barcode located within an image. |